Editor TabIndent Plugin Test

Paragraph with focusable item before editor.

Test TabIndent Plugin

1. the tabIndent plugin allows the use of the tab and shift-tab keys to indent list items.
2. another list element
3. and another
4. still one more

Ctrl-M also turns tab indent on/off. (The buttons should change checked status when the user types Ctrl-M, to indicate whether tab and shift-tab is enabled.)

Paragraph with focusable item after editor.